@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2006, 2007, 2008 Øyvind Kolås <pippin@gimp.org>
  *           2012 Ville Sokk <ville.sokk@gmail.com>
@@ -44,14 +44,14 @@
 #include <glib/gprintf.h>
 #include <glib/gstdio.h>
 
-#include "gegl.h"
+#include "gegl-buffer.h"
 #include "gegl-buffer-backend.h"
 #include "gegl-tile-backend.h"
 #include "gegl-tile-backend-file.h"
 #include "gegl-buffer-index.h"
 #include "gegl-buffer-types.h"
 #include "gegl-debug.h"
-#include "gegl-config.h"
+#include "gegl-buffer-config.h"
 
 
 #ifndef HAVE_FSYNC
@@ -177,7 +177,7 @@ gegl_tile_backend_file_push_queue (GeglFileBackendThreadParams *params)
   g_mutex_lock (&mutex);
 
   /* block if the queue has gotten too big */
-  while (queue_size > gegl_config ()->queue_size)
+  while (queue_size > gegl_buffer_config ()->queue_size)
     g_cond_wait (&max_cond, &mutex);
 
   params->file->pending_ops += 1;
@@ -294,7 +294,7 @@ gegl_tile_backend_file_writer_thread (gpointer ignored)
           g_free (params->source);
 
           /* unblock the main thread if the queue had gotten too big */
-          if (queue_size < gegl_config ()->queue_size)
+          if (queue_size < gegl_buffer_config ()->queue_size)
             g_cond_signal (&max_cond);
         }
 
@@ -862,10 +862,11 @@ gegl_tile_backend_file_command (GeglTileSource  *self,
         return gegl_tile_backend_file_flush (self, data, x, y, z);
 
       default:
-        g_assert (command < GEGL_TILE_LAST_COMMAND &&
-                  command >= 0);
+        break;
     }
-  return FALSE;
+
+  return gegl_tile_backend_command (GEGL_TILE_BACKEND (self),
+                                    command, x, y, z, data);
 }
 
 static void
@@ -879,7 +880,8 @@ gegl_tile_backend_file_set_property (GObject      *object,
   switch (property_id)
     {
       case PROP_PATH:
-        g_free (self->path);
+        if (self->path)
+          g_free (self->path);
         self->path = g_value_dup_string (value);
         break;
 
@@ -970,8 +972,11 @@ gegl_tile_backend_file_finalize (GObject *object)
       g_free (self->path);
     }
 
-  g_clear_object (&self->monitor);
-  g_clear_object (&self->file);
+  if (self->monitor)
+    g_object_unref (self->monitor);
+
+  if (self->file)
+    g_object_unref (self->file);
 
   g_cond_clear (&self->cond);
 
