@@ -11,7 +11,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with GEGL; if not, see <http://www.gnu.org/licenses/>.
+ * License along with GEGL; if not, see <https://www.gnu.org/licenses/>.
  *
  * Copyright 2011 Michael Muré <batolettre@gmail.com>
  *
@@ -37,27 +37,30 @@
 G_BEGIN_DECLS
 
 typedef enum {
-  GEGL_ABYSS_NONE,
-  GEGL_ABYSS_CLAMP,
-  GEGL_ABYSS_LOOP,
-  GEGL_ABYSS_BLACK,
-  GEGL_ABYSS_WHITE
-} GeglAbyssPolicy;
+  GEGL_DITHER_NONE,
+  GEGL_DITHER_FLOYD_STEINBERG,
+  GEGL_DITHER_BAYER,
+  GEGL_DITHER_RANDOM,
+  GEGL_DITHER_RANDOM_COVARIANT,
+  GEGL_DITHER_ARITHMETIC_ADD,
+  GEGL_DITHER_ARITHMETIC_ADD_COVARIANT,
+  GEGL_DITHER_ARITHMETIC_XOR,
+  GEGL_DITHER_ARITHMETIC_XOR_COVARIANT,
+} GeglDitherMethod;
 
-GType gegl_abyss_policy_get_type (void) G_GNUC_CONST;
-
-#define GEGL_TYPE_ABYSS_POLICY (gegl_abyss_policy_get_type ())
+GType gegl_dither_method_get_type (void) G_GNUC_CONST;
 
+#define GEGL_TYPE_DITHER_METHOD (gegl_dither_method_get_type ())
 
 typedef enum {
-  GEGL_ACCESS_READ      = 1 << 0,
-  GEGL_ACCESS_WRITE     = 1 << 1,
-  GEGL_ACCESS_READWRITE = (GEGL_ACCESS_READ | GEGL_ACCESS_WRITE)
-} GeglAccessMode;
+  GEGL_DISTANCE_METRIC_EUCLIDEAN,
+  GEGL_DISTANCE_METRIC_MANHATTAN,
+  GEGL_DISTANCE_METRIC_CHEBYSHEV
+} GeglDistanceMetric;
 
-GType gegl_access_mode_get_type (void) G_GNUC_CONST;
+GType gegl_distance_metric_get_type (void) G_GNUC_CONST;
 
-#define GEGL_TYPE_ACCESS_MODE (gegl_access_mode_get_type ())
+#define GEGL_TYPE_DISTANCE_METRIC (gegl_distance_metric_get_type ())
 
 
 typedef enum {
@@ -69,19 +72,6 @@ GType gegl_orientation_get_type (void) G_GNUC_CONST;
 
 #define GEGL_TYPE_ORIENTATION (gegl_orientation_get_type ())
 
-
-typedef enum {
-  GEGL_SAMPLER_NEAREST,
-  GEGL_SAMPLER_LINEAR,
-  GEGL_SAMPLER_CUBIC,
-  GEGL_SAMPLER_NOHALO,
-  GEGL_SAMPLER_LOHALO
-} GeglSamplerType;
-
-GType gegl_sampler_type_get_type (void) G_GNUC_CONST;
-
-#define GEGL_TYPE_SAMPLER_TYPE (gegl_sampler_type_get_type ())
-
 G_END_DECLS
 
 #endif /* __GEGL_ENUMS_H__ */
