@@ -26,6 +26,7 @@
  * Comments and improvements for this code are welcome.
  */
 
+#define GEGL_ITERATOR2_API
 #include "config.h"
 #include <glib/gi18n-lib.h>
 
@@ -405,10 +406,10 @@ process (GeglOperation       *operation,
     }
 
   iter = gegl_buffer_iterator_new (out_buf, roi, level, out_format,
-                                   GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE);
+                                   GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE, 1);
 
   while (gegl_buffer_iterator_next (iter))
-    c_process (operation, iter->data[0], iter->length, &iter->roi[0], level);
+    c_process (operation, iter->items[0].data, iter->length, &iter->items[0].roi, level);
 
   return  TRUE;
 }
