@@ -23,6 +23,7 @@
  *     We pick a pixel at random from the neighborhood of the current pixel.
  */
 
+#define GEGL_ITERATOR2_API
 #include "config.h"
 
 #include <glib/gi18n-lib.h>
@@ -88,14 +89,14 @@ process (GeglOperation       *operation,
   bpp = babl_format_get_bytes_per_pixel (format);
 
   gi = gegl_buffer_iterator_new (output, result, 0, format,
-                                 GEGL_ACCESS_WRITE, GEGL_ABYSS_CLAMP);
+                                 GEGL_ACCESS_WRITE, GEGL_ABYSS_CLAMP, 1);
 
   sampler = gegl_buffer_sampler_new_at_level (input, format, GEGL_SAMPLER_NEAREST, level);
 
   while (gegl_buffer_iterator_next (gi))
     {
-      gchar        *data = gi->data[0];
-      GeglRectangle roi  = gi->roi[0];
+      gchar        *data = gi->items[0].data;
+      GeglRectangle roi  = gi->items[0].roi;
       gint          i, j;
 
       for (j = roi.y; j < roi.y + roi.height ; j++)
@@ -142,7 +143,7 @@ gegl_op_class_init (GeglOpClass *klass)
   gegl_operation_class_set_keys (operation_class,
     "name",       "gegl:noise-pick",
     "title",      _("Noise Pick"),
-    "reference-hash", "0634d248731c51f4784749b934c05bd2",
+    "reference-hash", "9ce949376eb179e98e0c677911fa76e8",
     "categories", "noise",
     "description", _("Randomly interchange some pixels with neighbors"),
     NULL);
