@@ -16,6 +16,7 @@
  * Copyright (C) 2018 Ell
  */
 
+#define GEGL_ITERATOR2_API
 #include "config.h"
 
 #include <stddef.h>
@@ -101,7 +102,7 @@ test_unaligned_fill (FillFunc fill_func)
   gint                result = SUCCESS;
   const Babl         *format = babl_format ("RGBA float");
   gint                bpp    = babl_format_get_bytes_per_pixel (format);
-  gint                width, height;
+  gint                tile_width, tile_height;
   GeglRectangle       rect;
   GeglBuffer         *buffer;
   GeglBufferIterator *iter;
@@ -109,17 +110,19 @@ test_unaligned_fill (FillFunc fill_func)
   guchar              pixel1[bpp];
   guchar              pixel2[bpp];
 
-  g_object_get (gegl_config(),
-                "tile-width",  &width,
-                "tile-height", &height,
+  buffer = gegl_buffer_new (NULL, format);
+
+  g_object_get (buffer,
+                "tile-width",  &tile_width,
+                "tile-height", &tile_height,
                 NULL);
 
-  rect.x      = width  / 4;
-  rect.y      = height / 4;
-  rect.width  = width  / 2;
-  rect.height = height / 2;
+  rect.x      = tile_width  / 4;
+  rect.y      = tile_height / 4;
+  rect.width  = tile_width  / 2;
+  rect.height = tile_height / 2;
 
-  buffer = gegl_buffer_new (GEGL_RECTANGLE (0, 0, width, height), format);
+  gegl_buffer_set_extent (buffer, &rect);
 
   color = gegl_color_new ("white");
   gegl_buffer_set_color (buffer, NULL, color);
@@ -131,12 +134,12 @@ test_unaligned_fill (FillFunc fill_func)
   g_object_unref (color);
 
   iter = gegl_buffer_iterator_new (buffer, NULL, 0, format,
-                                   GEGL_BUFFER_READ, GEGL_ABYSS_NONE);
+                                   GEGL_BUFFER_READ, GEGL_ABYSS_NONE, 1);
 
   while (gegl_buffer_iterator_next (iter))
     {
-      const guchar        *src = iter->data[0];
-      const GeglRectangle *roi = &iter->roi[0];
+      const guchar        *src = iter->items[0].data;
+      const GeglRectangle *roi = &iter->items[0].roi;
       gint                 x;
       gint                 y;
 
